==> mcg_extension-1.0.0.tar.gz: lib/get/fav.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../design/mytheme.dart';
import '../extensions/getextensions.dart';
import '../preferences/mypreferences.dart';
import '../preferences/secure_preferences.dart';
import 'app_controller.dart';

class Fav {
  Fav._();

  static AppController get appController => Get.find<AppController>();

//* Root
  static const _preventDuplicates = false;
  static const _myPreventDuplicates = true;

  static Future<dynamic>? guardTo(Widget child, {Bindings? binding, bool preventDuplicates = _preventDuplicates, Transition? transition, Duration? duration}) async {
    if (hasConnection(warning: true)) return to(child, binding: binding, preventDuplicates: preventDuplicates, transition: transition, duration: duration);
    return false;
  }

  static Future<dynamic>? to(Widget child, {Bindings? binding, bool preventDuplicates = _preventDuplicates, Transition? transition, Duration? duration, bool? opaque}) async {
    final _time = DateTime.now().millisecondsSinceEpoch;
    if (_myPreventDuplicates && _time - readSeasonCache('gettoworking', 0)! < 500) return false;
    writeSeasonCache('gettoworking', _time);
    return Get.to(() => child, binding: binding, preventDuplicates: preventDuplicates, transition: transition, duration: duration, opaque: opaque);
  }

  static bool hasConnection({bool warning = true}) => appController.hasConnection(warning);
  static bool noConnection({bool warning = true}) => !hasConnection(warning: warning);

  //* preferences
  static MyPreferences get preferences => appController.preferences;
  static SecurePreferences get securePreferences => appController.securePreferences;

  ///Sadece uygulama seisonu icinde herhangi bir key valueyi uygulama kapanana kadar saklayabillirsin
  ///Get.put<Map<String,dynamic>>(<String,dynamic>{},tag: 'cacheBox'); Bunu maine ekle
  static Map<String, dynamic> get _cacheBox => appController.seasonCacheBox;
  static void writeSeasonCache(String key, dynamic data) => _cacheBox[key] = data;
  static T? readSeasonCache<T>(String key, [T? defaultValue]) => (_cacheBox[key] as T?) ?? defaultValue;

  //* design
  static Design get design => appController.design!;
  static Design get secondaryDesign => appController.secondaryDesign!;

//* Functions
  ///Gonderilen fonksiyon daha once calsitirildiysa   belitrilen sure gecmemisse callistirilmaz
  static void timeGuardFunction<M>(String saveKey, Duration duration, Function function, {bool usePreferences = false}) {
    if (!isTimeGuardNotAllowed(saveKey, duration: duration, usePreferences: usePreferences)) {
      function();
    }
  }

  static bool isTimeGuardNotAllowed(String saveKey, {Duration duration = const Duration(seconds: 2), bool usePreferences = false}) {
    final _lastUseTime = usePreferences ? preferences.getInt(saveKey, 0)! : readSeasonCache(saveKey, 0)!;
    if (DateTime.now().millisecondsSinceEpoch - _lastUseTime > duration.inMilliseconds) {
      usePreferences ? preferences.setInt(saveKey, DateTime.now().millisecondsSinceEpoch) : writeSeasonCache(saveKey, DateTime.now().millisecondsSinceEpoch);
      return false;
    }
    return true;
  }

  static void showLoading({String? loadingText}) {
    Get.dialog(WillPopScope(
      onWillPop: () async {
        return false;
      },
      child: Material(color: Colors.transparent, child: MyFlareIndicator(text: loadingText)),
    ));
  }

  static void removeLoading() {
    if (Get.isDialogOpen == true) Get.back();
  }
}

==> mcg_extension-1.0.1.tar.gz: lib/get/fav.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../design/mytheme.dart';
import '../preferences/mypreferences.dart';
import '../preferences/secure_preferences.dart';
import 'app_controller.dart';

class Fav {
  Fav._();

  static AppController get appController => Get.find<AppController>();

//* Root
  static const _preventDuplicates = false;
  static const _myPreventDuplicates = true;

  static Future<dynamic>? guardTo(Widget child, {Bindings? binding, bool preventDuplicates = _preventDuplicates, Transition? transition, Duration? duration}) async {
    if (hasConnection(warning: true)) return to(child, binding: binding, preventDuplicates: preventDuplicates, transition: transition, duration: duration);
    return false;
  }

  static Future<dynamic>? to(Widget child, {Bindings? binding, bool preventDuplicates = _preventDuplicates, Transition? transition, Duration? duration, bool? opaque}) async {
    final _time = DateTime.now().millisecondsSinceEpoch;
    if (_myPreventDuplicates && _time - readSeasonCache('gettoworking', 0)! < 500) return false;
    writeSeasonCache('gettoworking', _time);
    return Get.to(() => child, binding: binding, preventDuplicates: preventDuplicates, transition: transition, duration: duration, opaque: opaque);
  }

  static bool hasConnection({bool warning = true}) => appController.hasConnection(warning);
  static bool noConnection({bool warning = true}) => !hasConnection(warning: warning);

  //* preferences
  static MyPreferences get preferences => appController.preferences;
  static SecurePreferences get securePreferences => appController.securePreferences;

  ///Sadece uygulama seisonu icinde herhangi bir key valueyi uygulama kapanana kadar saklayabillirsin
  ///Get.put<Map<String,dynamic>>(<String,dynamic>{},tag: 'cacheBox'); Bunu maine ekle
  static Map<String, dynamic> get _cacheBox => appController.seasonCacheBox;
  static void writeSeasonCache(String key, dynamic data) => _cacheBox[key] = data;
  static T? readSeasonCache<T>(String key, [T? defaultValue]) => (_cacheBox[key] as T?) ?? defaultValue;

  //* design
  static Design get design => appController.design!;
  static Design get secondaryDesign => appController.secondaryDesign!;

//* Functions
  ///Gonderilen fonksiyon daha once calsitirildiysa   belitrilen sure gecmemisse callistirilmaz
  static void timeGuardFunction<M>(String saveKey, Duration duration, Function function, {bool usePreferences = false, Function()? elseFunction}) {
    if (!isTimeGuardNotAllowed(saveKey, duration: duration, usePreferences: usePreferences)) {
      function();
    } else if (elseFunction != null) {
      elseFunction();
    }
  }

//! bir asagidaki ve bunun isimleri yaptiklari isi ifade etmiyor
//! birisinde sadece kontrol var
  static bool isTimeGuardNotAllowed(String saveKey, {Duration duration = const Duration(seconds: 2), bool usePreferences = false}) {
    final _lastUseTime = usePreferences ? preferences.getInt(saveKey, 0)! : readSeasonCache(saveKey, 0)!;
    if (DateTime.now().millisecondsSinceEpoch - _lastUseTime > duration.inMilliseconds) {
      usePreferences ? preferences.setInt(saveKey, DateTime.now().millisecondsSinceEpoch) : writeSeasonCache(saveKey, DateTime.now().millisecondsSinceEpoch);
      return false;
    }
    return true;
  }

  static bool checkTimeGuardNotAllowed(String saveKey, {Duration duration = const Duration(seconds: 2), bool usePreferences = false}) {
    final _lastUseTime = usePreferences ? preferences.getInt(saveKey, 0)! : readSeasonCache(saveKey, 0)!;
    if (DateTime.now().millisecondsSinceEpoch - _lastUseTime > duration.inMilliseconds) {
      return false;
    }
    return true;
  }

  // static void showLoading({String? loadingText}) {
  //   Get.dialog(WillPopScope(
  //     onWillPop: () async {
  //       return false;
  //     },
  //     child: Material(color: Colors.transparent, child: MyFlareIndicator(text: loadingText)),
  //   ));
  // }

  // static void removeLoading() {
  //   if (Get.isDialogOpen == true) Get.back();
  // }

  ///Sinav okutma islemi sonrasi hicbir turlu remove loading olmuyordu bu gibi yerler icin
  ///
  // static Future<void> forceRemoveLoading() async {
  //   while (Get.isDialogOpen == true) {
  //     Get.back();
  //     await 100.wait;
  //   }
  // }
}
